/*
 * Copyright 2017 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.firebase.database.core;

import com.google.firebase.database.connection.ConnectionContext;
import com.google.firebase.database.connection.HostInfo;
import com.google.firebase.database.connection.PersistentConnection;
import com.google.firebase.database.core.persistence.PersistenceManager;

import java.util.concurrent.ScheduledExecutorService;

public interface Platform {

  String DEVICE = "AdminJava";

  EventTarget newEventTarget(Context ctx);

  RunLoop newRunLoop(Context ctx);

  AuthTokenProvider newAuthTokenProvider(ScheduledExecutorService executorService);

  PersistentConnection newPersistentConnection(
      Context context,
      ConnectionContext connectionContext,
      HostInfo info,
      PersistentConnection.Delegate delegate);

  String getUserAgent(Context ctx);

  String getPlatformVersion();

  PersistenceManager createPersistenceManager(Context ctx, String firebaseId);
}
